Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(74)

Unified Diff: mojo/shell/standalone/android/background_application_loader.cc

Issue 1675153002: ApplicationImpl->ShellConnection, mojom::Application->mojom::ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@ci2
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/shell/standalone/android/background_application_loader.cc
diff --git a/mojo/shell/standalone/android/background_application_loader.cc b/mojo/shell/standalone/android/background_application_loader.cc
index 8bd3869e38a7e4acb609c9baa915d7aae38fbb46..446ce42a43324bf68fc7c8e08b3cb97268152817 100644
--- a/mojo/shell/standalone/android/background_application_loader.cc
+++ b/mojo/shell/standalone/android/background_application_loader.cc
@@ -29,12 +29,12 @@ BackgroundApplicationLoader::~BackgroundApplicationLoader() {
void BackgroundApplicationLoader::Load(
const GURL& url,
- InterfaceRequest<mojom::Application> application_request) {
- DCHECK(application_request.is_pending());
+ InterfaceRequest<mojom::ShellClient> request) {
+ DCHECK(request.is_pending());
if (!thread_) {
// TODO(tim): It'd be nice if we could just have each Load call
// result in a new thread like DynamicService{Loader, Runner}. But some
// loaders are creating multiple ApplicationImpls (NetworkApplicationLoader)
// sharing a delegate (etc). So we have to keep it single threaded, wait
// for the thread to initialize, and post to the TaskRunner for subsequent
// Load calls for now.
@@ -47,8 +47,7 @@ void BackgroundApplicationLoader::Load(
task_runner_->PostTask(
FROM_HERE,
base::Bind(&BackgroundApplicationLoader::LoadOnBackgroundThread,
- base::Unretained(this), url,
- base::Passed(&application_request)));
+ base::Unretained(this), url, base::Passed(&request)));
}
void BackgroundApplicationLoader::Run() {
@@ -65,9 +64,9 @@ void BackgroundApplicationLoader::Run() {
void BackgroundApplicationLoader::LoadOnBackgroundThread(
const GURL& url,
- InterfaceRequest<mojom::Application> application_request) {
+ InterfaceRequest<mojom::ShellClient> request) {
DCHECK(task_runner_->RunsTasksOnCurrentThread());
- loader_->Load(url, std::move(application_request));
+ loader_->Load(url, std::move(request));
}
} // namespace shell
@@ -29,12 +29,12 @@ BackgroundApplicationLoader::~BackgroundApplicationLoader() {
// TODO(tim): It'd be nice if we could just have each Load call
// result in a new thread like DynamicService{Loader, Runner}. But some
- // loaders are creating multiple ApplicationImpls (NetworkApplicationLoader)
+ // loaders are creating multiple ShellConnections (NetworkApplicationLoader)
// sharing a delegate (etc). So we have to keep it single threaded, wait
// for the thread to initialize, and post to the TaskRunner for subsequent

Powered by Google App Engine
This is Rietveld 408576698